#
# spec file for package bugzilla
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bugzilla
Version:        5.0.6
Release:        7.1
Summary:        Bug tracker for software development
License:        MPL-2.0
Group:          Development/Tools/Other
URL:            http://bugzilla.org/
Source:         http://ftp.mozilla.org/pub/mozilla.org/webtools/%{name}-%{version}.tar.gz
Source2:        http://downloads.sourceforge.net/project/bugzilla-de/5.0/5.0.4/%{name}-de-5.0.4-2.utf-8.tar.gz
Source3:        MPL-2.0.html
Source4:        %{name}.conf
Source5:        %{name}-rpmlintrc
Patch1:         fix_whine_error.patch
Patch2:         modernize-bugzilla-submit.patch
Patch3:         bugzilla-py3-jb2bz.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(systemd)
Requires:       patchutils
Requires:       perl-Authen-SASL
#Recommends:		RadiusPerl
Requires:       perl-Cache-Memcached
Requires:       perl-Chart >= 2.4.1
Requires:       perl-DBD-Pg >= 2.7.0
Requires:       perl-DBD-SQLite >= 1.29
Requires:       perl-DBD-mysql >= 4.001
Requires:       perl-DBI >= 1.614
Requires:       perl-Daemon-Generic
Requires:       perl-DateTime >= 0.75
Requires:       perl-DateTime-TimeZone >= 1.64
Requires:       perl-Digest-SHA1
Requires:       perl-Email-MIME >= 1.904
Requires:       perl-Email-Reply
Requires:       perl-Email-Send >= 2.02
Requires:       perl-Email-Sender >= v1.300011
Requires:       perl-Encode >= 2.21
Requires:       perl-Encode-Detect
Requires:       perl-File-Copy-Recursive
Requires:       perl-File-MimeInfo
Requires:       perl-File-Slurp >= 9999.13
Requires:       perl-File-Which
Requires:       perl-GD >= 1.20
Requires:       perl-GDGraph
Requires:       perl-GDTextUtil
Requires:       perl-HTML-FormatText-WithLinks >= 0.13
Requires:       perl-HTML-Parser >= 3.67
Requires:       perl-HTML-Scrubber
Requires:       perl-IO-stringy
Requires:       perl-JSON-RPC
Requires:       perl-JSON-XS >= 2.01
Requires:       perl-List-MoreUtils >= 0.32
Requires:       perl-MIME-tools >= 5.406
Requires:       perl-Math-Random-ISAAC >= 1.0.1
Requires:       perl-Module-Pluggable
Requires:       perl-Net-SMTP-SSL >= 1.01
Requires:       perl-Object-Pluggable
Requires:       perl-PatchReader >= 0.9.6
Requires:       perl-SOAP-Lite >= 0.712
Requires:       perl-Template-GD
Requires:       perl-Template-Toolkit >= 2.24
Requires:       perl-Test-Taint >= 1.0.6
Requires:       perl-TheSchwartz >= 1.07
Requires:       perl-TimeDate >= 2.23
Requires:       perl-URI >= 1.55
Requires:       perl-XML-Twig
Requires:       perl-XMLRPC-Lite >= 0.712
Requires:       perl-base >= 5.8.1
Requires:       perl-ldap
Requires:       perl-libwww-perl
Requires:       perl(CGI) >= 5.8.1
Recommends:     perl-DBD-Oracle >= 1.19
BuildArch:      noarch
%{?systemd_requires}

%description
Bugzilla is server software designed to help you manage software
development.

* Optimized database structure for increased performance and
  scalability
* Excellent security to protect confidentiality
* Advanced query tool that can remember your searches
* Integrated email capabilities
* Editable user profiles and comprehensive email preferences
* Comprehensive permissions system
* Proven under fire as Mozilla's bug tracking system

%package lang-de
Summary:        German language files for bugzilla
Group:          Development/Tools/Other
Requires:       %{name} = %{version}-%{release}

%description lang-de
This package includes german language files for bugzilla

%package apache
Summary:        Apache configuration for %{name}
Group:          Productivity/Networking/Web/Utilities
BuildRequires:  apache2
Requires:       apache2
Requires:       apache2-mod_perl >= 1.999022
#Recommonds:	Apache-SizeLimit
Supplements:    packageand(apache2:%name)

%description apache
This subpackage contains the Apache configuration files

%prep
%setup -q
%autopatch -p1
# rpmlint
sed -i -e 's|\/usr\/bin\/env perl|\/usr\/bin\/perl|g' contrib/perl-fmt
#
tar -xzf %{SOURCE2}  --directory "template"
cd template/de
cd ../..

%build

%install
# Ensure shebang shell scripts have executable bit set
for file in `find -type f -perm /664`; do
  if head -1 $file | grep -E '^\#!' &>/dev/null; then
    chmod a+x $file
  fi
done
# Remove the execute bit from files that don't start with #!
for file in `find -type f -perm /111`; do
  if head -1 $file | grep -E -v '^\#!' &>/dev/null; then
    chmod a-x $file
  fi
done
# Hello bugzilla devs...
find . -type d "(" -name .bzr -o -name .git ")" \
	-exec rm -Rf "{}" "+"
find . -type f "(" -name ".git*" -o -name ".bzr*" -o -name ".travis*" -o -name ".buildinfo*" ")" \
    -exec rm -Rf "{}" "+"
find . -type f -print0 | xargs -0r grep -l '^#!' | xargs -r chmod a+x
find . -type f -print0 | xargs -0r grep -l '^#!' | \
	xargs -r perl -i -pe 's{^#!%{_prefix}/local/}{#!%{_prefix}/}' "{}" "+"
mkdir -p "%{buildroot}%{apache_serverroot}"
cp -a . "%{buildroot}%{apache_serverroot}/%{name}"

%if %{suse_version} >= 1600
# both occurences of /usr/bin/python3 are introduced by our patches, is there a more straightforward way?
%python3_fix_shebang_path %{buildroot}%{apache_serverroot}/%{name}/contrib/bugzilla-submit/bugzilla-submit %{buildroot}%{apache_serverroot}/%{name}/contrib/jb2bz.py
%endif

%fdupes %{buildroot}/srv

cp "%{SOURCE3}" .
#install bugzilla.conf to apache conf.d
install -D -m0640 %{SOURCE4} %{buildroot}%{apache_sysconfdir}/conf.d/bugzilla.conf
# fix apache serverroot
sed -i -e 's|@APACHE_SERVERROOT@|%{apache_serverroot}|g' %{buildroot}%{apache_sysconfdir}/conf.d/bugzilla.conf
# remove included .htaccess which has been moved to bugzilla.conf
rm %{buildroot}%{apache_serverroot}/%{name}/.htaccess

%files
%doc MPL-2.0.html
%dir %{apache_serverroot}
%defattr(-,%{apache_user},root)
# exclude language de_DE
%exclude %{apache_serverroot}/bugzilla/template/de
%{apache_serverroot}/bugzilla

%files lang-de
%dir %{apache_serverroot}
%defattr(0644,%{apache_user},root,755)
%{apache_serverroot}/bugzilla/template/de

%files apache
%attr(-,%{apache_user},%{apache_group}) %config(noreplace) %{apache_sysconfdir}/conf.d/bugzilla.conf

%changelog
* Sat Sep 28 2024 ecsos <ecsos@opensuse.org>
- Fix installcheck failure from obs staging-bot after last change
  of [bsc#1231027]:
  /srv/www [mode mismatch: d755 wwwrun:root, d755 root:root]
* Sat Sep 28 2024 Thorsten Kukuk <kukuk@suse.com>
- Add /srv/www directories to filelist [bsc#1231027]
* Thu Jun 13 2024 Markéta Machová <mmachova@suse.com>
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Tue Apr 18 2023 Max Lin <mlin@suse.com>
- Port jb2bz.py to python3
  * Add bugzilla-py3-jb2bz.patch
* Tue Aug 31 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add modernize-bugzilla-submit.patch:
  - Port bugzilla-submit to Python 3.
* Sun Dec 13 2020 ecsos <ecsos@opensuse.org>
- Use apache-rpm-macros.
- Put apache configuration files in separate subpackage.
- Remove %%service_add_post and %%server_del_postun apache2.service
  from spec.
- Fix two rpmlint errors.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Wed Jul 17 2019 ecsos@opensuse.org
- Update to 5.0.6
  This release contains a schema change to the flagtypes table,
  allowing for many more flagtypes.
  - The flagtypes table should have been using a mediumint for
    several releases, but due to a bug in the schema migration code
    this never happened.
- Changes from 5.0.5
  This release reformats the code according to the same
  conventions as the popular Mojolicious product and includes a
  .perltidyrc to do the same. You may use whatever coding style you
  want, but all files commited to the repo must be reformatted
  according to those rules.
  Additionally, we no longer follow the same release process as
  before. Releases will be more frequent.
  - As it is now 2019, the bugs_fulltext table is now InnoDB instead
    of MyISAM. This may cause upgrade headaches.
- Update german language to 5.0.4-2.
- Drop bugzilla-de-tagfix.patch because now in upstream language.
- Run spec-cleaner.
* Fri Mar 23 2018 ecsos@opensuse.org
- update german language to 5.0.4
- Add patch bugzilla-de-tagfix.patch to fix "missing closing tag
  in german language pack" (boo#1015765).
  Thanks voorburg@gmx.net.
* Mon Mar  5 2018 ecsos@opensuse.org
- update to 5.0.4
  This release fixes one security issue.
  See the Security Advisory for details.
  - checksetup.pl would fail to update Chart storage during
    pre-3.6 to 5.0 upgrade. (Bug 1273846)
  - editflagtypes.cgi would crash when classifications are enabled
    and the user did not have global editcomponents privileges.
    (Bug 1310728)
  - The File::Slurp would trigger warnings on perl 5.24.
    (Bug 1301887)
  - All the time entries in the 'when' column had the correct date
    but the time was fixed to 00:00 when using Sqlite.
    (Bug 1303702)
* Wed Oct  4 2017 matwey.kornilov@gmail.com
- rename bugzilla.rpmlintrc to bugzilla-rpmlintrc
  to follow guidelines
* Tue Oct  3 2017 matwey.kornilov@gmail.com
- put bugzilla.rpmlintrc into Sources
* Tue Jul 26 2016 ecsos@opensuse.org
- update german language to 5.0.3-1
* Thu Jun 16 2016 ecsos@opensuse.org
- update to 5.0.3
  This release fixes one security issue and some bug fixes.
  https://www.bugzilla.org/releases/5.0.3/release-notes.html
  - A regression in Bugzilla 5.0.2 caused whine.pl to be unable
    to send emails due to a missing subroutine. (Bug 1235395)
  - The Encode module changed the way it encodes strings,
    causing email addresses in emails sent by Bugzilla to be encoded,
    preventing emails from being correctly delivered to recipients.
    We now encode email headers correctly. (Bug 1246228)
  - Fix additional taint issues with Strawberry Perl.
    (Bug 987742 and bug 1089448)
  - When exporting a buglist as a CSV file, fields starting with
    either "=", "+", "-" or "@" are preceded by a space to not
    trigger formula execution in Excel. (Bug 1259881)
  - An extension which allows user-controlled data to be used as
    a link in tabs could trigger XSS if the data is not correctly
    sanitized. Bugzilla no longer relies on the extension to do the
    sanity check. A vanilla installation is not affected as no tab
    is user-controlled. (Bug 1250114)
  - Extensions can now easily override the favicon used for the
    Bugzilla website. (Bug 1250264)
- Security fix:
  * (CVE-2016-2803)
    https://www.bugzilla.org/security/4.4.11/
- rework patch fix_whine_error.patch because most now in upstream
* Mon Jan 25 2016 ecsos@opensuse.org
- update german language to 5.0.2-1
* Tue Jan 19 2016 ecsos@opensuse.org
- fix error "Undefined subroutine..." in whine.pl
  https://bugzilla.mozilla.org/show_bug.cgi?id=1235395
* Sun Jan  3 2016 ecsos@opensuse.org
- update to 5.0.2
  This release fixes two security issues and some bug fixes.
  https://www.bugzilla.org/releases/5.0.2/release-notes.html
  - mod_perl now works correctly with mod_access_compat turned off
    on Apache 2.4.
    To regenerate the .htaccess files, you must first delete all
    existing ones in subdirectories:
    find . -mindepth 2 -name .htaccess -exec rm -f {} \;
    You must then run checksetup.pl again to recreate them with
    the correct syntax. (Bug 1223790)
  - Emails sent by Bugzilla are now correctly encoded as UTF-8.
    (Bug 714724)
  - Strawberry Perl is now fully supported on Windows.
    (Bug 1089448 and bug 987742)
  - The XML-RPC API now works with IIS on Windows. (Bug 708252)
  - Some queries should now be faster on PostgreSQL. (Bug 1184431)
- Security fixes:
  * (CVE-2015-8508)
    https://www.bugzilla.org/security/4.2.15/
    https://bugzilla.mozilla.org/show_bug.cgi?id=1221518
  * (CVE-2015-8509)
    https://www.bugzilla.org/security/4.2.15/
    https://bugzilla.mozilla.org/show_bug.cgi?id=1232785
* Fri Sep 18 2015 ecsos@opensuse.org
- update to 5.0.1
  This update fixes several vulnerabilities
  https://www.bugzilla.org/releases/5.0.1/release-notes.html
- Security fixes:
  * (CVE-2015-4499)
    https://www.bugzilla.org/security/4.2.14/
    https://bugzilla.mozilla.org/show_bug.cgi?id=1202447
* Mon Jul 13 2015 ecsos@opensuse.org
- update to 5.0
  https://www.bugzilla.org/releases/5.0/release-notes.html
- update german language to 5.0
- fix no acccess under apache 2.4 in bugzilla.conf
* Tue Jun 23 2015 ecsos@opensuse.org
- add perl-Module-Pluggable and perl-Object-Pluggable to Requires:
  because it will be removed in next perl major release.
* Thu Apr 23 2015 ecsos@opensuse.org
- update to 4.4.9
  - Users who are not in the insidergroup were able to determine
    if some specific user made a private comment in bugs.
    (Bug 1151290)
  - Due to a regression caused by bug 1090275, the WebService
    methods Bug.get_bugs and Bug.get_history were no longer
    allowed. (Bug 1154099)
  - Bugzilla now supports the new .htaccess format from Apache 2.4.
    (Bug 1121477)
  - A regression in Bugzilla 4.4.3 due to CVE-2014-1517 caused the
    admin's password to be ignored when starting a sudo session.
    (Bug 1132887)
- update bugzilla.conf with new from .htaccess
- update german language to 4.4.9
* Wed Mar 25 2015 jweberhofer@weberhofer.at
- Moved code from .htaccess file into bugzilla.conf
- Removed BOM from bugzilla.conf
- Explicitly set directory rights for gernam language pack
- Cleaned up spec file
* Mon Mar  2 2015 ecsos@opensuse.org
- update to 4.4.8
  - Fixing a regression caused by bug 10902750,
    JSON-RPC API calls could crash in certain cases instead of
    displaying the proper error message. (Bug 1124716)
- changes from 4.4.7
  - The Bug.add_comment WebService method now returns the
    correct ID for the newly created bug comment. (Bug 1111043)
    Fixing a regression caused by CVE-2014-1571 (bug 1064140),
    comments made while setting a flag from the attachment
    details page are again included in the flag notification email.
    (Bug 1082887)
- update german language to 4.4.8
- remove cvs check and add git check for unneeded files
* Tue Oct 28 2014 ecsos@opensuse.org
- insert BuildRequires: apache, so apache dirs not owned by
  this package
- insert bugzilla.conf for apache
* Wed Oct  8 2014 ecsos@opensuse.org
- Update to 4.4.6
* Mon Sep 22 2014 ecsos@opensuse.org
- Update to 4.4.5
- added german template
- correct and upgrade spec
* Sat Apr 16 2011 jengelh@medozas.de
- Update to upstream release 4.1.1
* Sat Sep  4 2010 jengelh@medozas.de
- Remove unwanted "CVS" directories from installation
- Remove unwanted ".cvsignore" files
- Change rpmgroup for rpmlint
- Mark shebang scripts as executable (chmod +x)
* Tue Aug 24 2010 jengelh@medozas.de
- Update to new upstream release 3.6.2
  * four security fixes
